Problem

Struct Problem 

pub struct Problem<'cost> { /* private fields */ }

Implementations

Source

impl Problem<'_>

pub unsafe fn SetParameterBlockConstant( self: Pin<&mut Self>, values: *const f64, )

Set parameter to be constant.

Safety

values must point to already added parameter block.

pub unsafe fn SetParameterBlockVariable(self: Pin<&mut Self>, values: *mut f64)

Set parameter to vary.

Safety

values must point to already added parameter block.

pub unsafe fn IsParameterBlockConstant(&self, values: *const f64) -> bool

Check if parameter is constant.

Safety

values must point to already added parameter block.

pub unsafe fn SetParameterLowerBound( self: Pin<&mut Self>, values: *mut f64, index: i32, lower_bound: f64, )

Set lower bound for a component of a parameter block.

Safety

values must point to already added parameter block.

pub unsafe fn SetParameterUpperBound( self: Pin<&mut Self>, values: *mut f64, index: i32, upper_bound: f64, )

Set upper bound for a component of a parameter block.

Safety

values must point to already added parameter block.

pub fn NumParameterBlocks(&self) -> i32

pub fn NumParameters(&self) -> i32

pub fn NumResidualBlocks(&self) -> i32

pub fn NumResiduals(&self) -> i32

pub unsafe fn ParameterBlockSize(&self, values: *const f64) -> i32

Number of components of the parameter.

Safety

values must point to already added parameter block.

pub unsafe fn HasParameterBlock(&self, values: *const f64) -> bool

Checks if problem has a given parameter.

Safety

It should be safe to call this function with any pointer.