pub struct Problem<'cost> { /* private fields */ }Implementations
Sourceimpl Problem<'_>
impl Problem<'_>
Sourcepub unsafe fn SetParameterBlockConstant(
self: Pin<&mut Self>,
values: *const f64,
)
pub unsafe fn SetParameterBlockConstant( self: Pin<&mut Self>, values: *const f64, )
Sourcepub unsafe fn SetParameterBlockVariable(self: Pin<&mut Self>, values: *mut f64)
pub unsafe fn SetParameterBlockVariable(self: Pin<&mut Self>, values: *mut f64)
Sourcepub unsafe fn IsParameterBlockConstant(&self, values: *const f64) -> bool
pub unsafe fn IsParameterBlockConstant(&self, values: *const f64) -> bool
Sourcepub unsafe fn SetParameterLowerBound(
self: Pin<&mut Self>,
values: *mut f64,
index: i32,
lower_bound: f64,
)
pub unsafe fn SetParameterLowerBound( self: Pin<&mut Self>, values: *mut f64, index: i32, lower_bound: f64, )
Set lower bound for a component of a parameter block.
Safety
values must point to already added parameter block.
Sourcepub unsafe fn SetParameterUpperBound(
self: Pin<&mut Self>,
values: *mut f64,
index: i32,
upper_bound: f64,
)
pub unsafe fn SetParameterUpperBound( self: Pin<&mut Self>, values: *mut f64, index: i32, upper_bound: f64, )
Set upper bound for a component of a parameter block.
Safety
values must point to already added parameter block.
pub fn NumParameterBlocks(&self) -> i32
pub fn NumParameters(&self) -> i32
pub fn NumResidualBlocks(&self) -> i32
pub fn NumResiduals(&self) -> i32
Sourcepub unsafe fn ParameterBlockSize(&self, values: *const f64) -> i32
pub unsafe fn ParameterBlockSize(&self, values: *const f64) -> i32